"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.extractPuppeteerResponse = void 0;
const tslib_1 = require("tslib");
const debug_1 = tslib_1.__importDefault(require("debug"));
const logger_1 = tslib_1.__importDefault(require("../logger"));
const logger = debug_1.default('teremock:driver:puppeteer:response');
async function extractPuppeteerResponse(puppeteerResponse, options) {
    const puppeteerRequest = puppeteerResponse.request();
    let requestBody;
    let responseBody;
    try {
        responseBody = await puppeteerResponse.json();
    }
    catch (e) {
        logger('« puppeteerResponse.json() error:', e.message);
        try {
            responseBody = await puppeteerResponse.text();
            logger(`« response body starts with: ${responseBody === null || responseBody === void 0 ? void 0 : responseBody.substr(0, 20)}`);
        }
        catch (e) {
            logger('« puppeteerResponse.text() error:', e.message);
        }
    }
    requestBody = puppeteerRequest.postData();
    if (requestBody) {
        try {
            requestBody = JSON.parse(requestBody);
        }
        catch (e) { }
    }
    const { teremockRequest } = puppeteerRequest;
    const request = {
        url: puppeteerRequest.url(),
        method: puppeteerRequest.method(),
        headers: puppeteerRequest.headers(),
        body: requestBody,
        resourceType: puppeteerRequest.resourceType(),
        id: teremockRequest ? teremockRequest.id : -1,
        timestamp: teremockRequest ? teremockRequest.timestamp : 0,
        order: teremockRequest ? teremockRequest.order : -1,
    };
    const response = {
        url: puppeteerResponse.url(),
        status: puppeteerResponse.status(),
        headers: puppeteerResponse.headers(),
        body: responseBody,
        timestamp: options.timestamp,
        order: options.order,
        // ttfb: timestamp - puppeteerRequest.timestamp,
    };
    logger(`got the response, sending it to teremock core`);
    const { __meta } = puppeteerRequest;
    if (!__meta) {
        logger_1.default.warn(`__meta was not found in puppeteerRequest. Probably it was made before teremock.start()`);
        logger_1.default.warn(`Passing the response witout storing it. The request was:`, request);
    }
    return { request, response, __meta };
}
exports.extractPuppeteerResponse = extractPuppeteerResponse;
