"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.extractPlaywrightResponse = void 0;
const tslib_1 = require("tslib");
const debug_1 = tslib_1.__importDefault(require("debug"));
const logger_1 = tslib_1.__importDefault(require("../logger"));
const logger = debug_1.default('teremock:driver:puppeteer:response');
async function extractPlaywrightResponse(playwrightResponse, options) {
    const playwrightRequest = playwrightResponse.request();
    let requestBody;
    let responseBody;
    try {
        responseBody = await playwrightResponse.json();
    }
    catch (e) {
        logger('« playwrightResponse.json() error:', e.message);
        try {
            responseBody = await playwrightResponse.text();
            logger(`« response body starts with: ${responseBody === null || responseBody === void 0 ? void 0 : responseBody.substr(0, 20)}`);
        }
        catch (e) {
            logger('« playwrightResponse.text() error:', e.message);
        }
    }
    try {
        requestBody = JSON.parse(playwrightRequest.postData());
    }
    catch (e) {
        requestBody = playwrightRequest.postData();
    }
    // @ts-expect-error
    const { teremockRequest } = playwrightRequest;
    const request = {
        url: playwrightRequest.url(),
        method: playwrightRequest.method(),
        headers: playwrightRequest.headers(),
        body: requestBody,
        resourceType: playwrightRequest.resourceType(),
        id: teremockRequest ? teremockRequest.id : -1,
        timestamp: teremockRequest ? teremockRequest.timestamp : 0,
        order: teremockRequest ? teremockRequest.order : -1,
    };
    const response = {
        url: playwrightResponse.url(),
        status: playwrightResponse.status(),
        headers: playwrightResponse.headers(),
        body: responseBody,
        timestamp: options.timestamp,
        order: options.order,
        // ttfb: timestamp - playwrightRequest.timestamp,
    };
    logger(`got the response, sending it to teremock core`);
    const { __meta } = playwrightRequest;
    if (!__meta) {
        logger_1.default.warn(`__meta was not found in playwrightRequest. Probably it was made before teremock.start()`);
        logger_1.default.warn(`Passing the response witout storing it. The request was:`, request);
    }
    return { request, response, __meta };
}
exports.extractPlaywrightResponse = extractPlaywrightResponse;
